==> aws-solutions-konstruk.aws-cognito-apigateway-lambda-0.8.0.tar.gz: package/lib/index.d.ts <==
/**
 *  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import * as api from '@aws-cdk/aws-apigateway';
import * as lambda from '@aws-cdk/aws-lambda';
import * as cognito from '@aws-cdk/aws-cognito';
import { Construct } from '@aws-cdk/core';
/**
 * @summary The properties for the CognitoToApiGatewayToLambda Construct
 */
export interface CognitoToApiGatewayToLambdaProps {
    /**
     * Whether to create a new Lambda function or use an existing Lambda function.
     * If set to false, you must provide a lambda function object as `existingLambdaObj`
     *
     * @default - true
     */
    readonly deployLambda: boolean;
    /**
     * Existing instance of Lambda Function object.
     * If `deploy` is set to false only then this property is required
     *
     * @default - None
     */
    readonly existingLambdaObj?: lambda.Function;
    /**
     * Optional user provided props to override the default props for the Lambda function.
     * If `deploy` is set to true only then this property is required
     *
     * @default - Default props are used
     */
    readonly lambdaFunctionProps?: lambda.FunctionProps;
    /**
     * Optional user provided props to override the default props for the API Gateway.
     *
     * @default - Default props are used
     */
    readonly apiGatewayProps?: api.LambdaRestApiProps | any;
    /**
     * Optional user provided props to override the default props
     *
     * @default - Default props are used
     */
    readonly cognitoUserPoolProps?: cognito.UserPoolProps;
    /**
     * Optional user provided props to override the default props
     *
     * @default - Default props are used
     */
    readonly cognitoUserPoolClientProps?: cognito.UserPoolClientProps;
}
export declare class CognitoToApiGatewayToLambda extends Construct {
    private userpool;
    private userpoolclient;
    private api;
    private fn;
    /**
     * @summary Constructs a new instance of the CognitoToApiGatewayToLambda class.
     * @param {cdk.App} scope - represents the scope for all the resources.
     * @param {string} id - this is a a scope-unique id.
     * @param {CognitoToApiGatewayToLambdaProps} props - user provided props for the construct
     * @since 0.8.0
     * @access public
     */
    constructor(scope: Construct, id: string, props: CognitoToApiGatewayToLambdaProps);
    /**
     * @summary Retruns an instance of api.RestApi created by the construct.
     * @returns {api.RestApi} Instance of RestApi created by the construct
     * @since 0.8.0
     * @access public
     */
    restApi(): api.RestApi;
    /**
     * @summary Retruns an instance of lambda.Function created by the construct.
     * @returns {lambda.Function} Instance of Function created by the construct
     * @since 0.8.0
     * @access public
     */
    lambdaFunction(): lambda.Function;
    /**
     * @summary Retruns an instance of cognito.UserPool created by the construct.
     * @returns {cognito.UserPool} Instance of UserPool created by the construct
     * @since 0.8.0
     * @access public
     */
    userPool(): cognito.UserPool;
    /**
     * @summary Retruns an instance of cognito.UserPoolClient created by the construct.
     * @returns {cognito.UserPoolClient} Instance of UserPoolClient created by the construct
     * @since 0.8.0
     * @access public
     */
    userPoolClient(): cognito.UserPoolClient;
}

==> aws-solutions-konstruk.aws-cognito-apigateway-lambda-0.8.1.tar.gz: package/lib/index.d.ts <==
/**
 *  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import * as api from '@aws-cdk/aws-apigateway';
import * as lambda from '@aws-cdk/aws-lambda';
import * as cognito from '@aws-cdk/aws-cognito';
import { Construct } from '@aws-cdk/core';
/**
 * @summary The properties for the CognitoToApiGatewayToLambda Construct
 */
export interface CognitoToApiGatewayToLambdaProps {
    /**
     * Whether to create a new Lambda function or use an existing Lambda function.
     * If set to false, you must provide a lambda function object as `existingLambdaObj`
     *
     * @default - true
     */
    readonly deployLambda: boolean;
    /**
     * Existing instance of Lambda Function object.
     * If `deploy` is set to false only then this property is required
     *
     * @default - None
     */
    readonly existingLambdaObj?: lambda.Function;
    /**
     * Optional user provided props to override the default props for the Lambda function.
     * If `deploy` is set to true only then this property is required
     *
     * @default - Default props are used
     */
    readonly lambdaFunctionProps?: lambda.FunctionProps;
    /**
     * Optional user provided props to override the default props for the API Gateway.
     *
     * @default - Default props are used
     */
    readonly apiGatewayProps?: api.LambdaRestApiProps | any;
    /**
     * Optional user provided props to override the default props
     *
     * @default - Default props are used
     */
    readonly cognitoUserPoolProps?: cognito.UserPoolProps;
    /**
     * Optional user provided props to override the default props
     *
     * @default - Default props are used
     */
    readonly cognitoUserPoolClientProps?: cognito.UserPoolClientProps;
}
export declare class CognitoToApiGatewayToLambda extends Construct {
    private userpool;
    private userpoolclient;
    private api;
    private fn;
    /**
     * @summary Constructs a new instance of the CognitoToApiGatewayToLambda class.
     * @param {cdk.App} scope - represents the scope for all the resources.
     * @param {string} id - this is a a scope-unique id.
     * @param {CognitoToApiGatewayToLambdaProps} props - user provided props for the construct
     * @since 0.8.0
     * @access public
     */
    constructor(scope: Construct, id: string, props: CognitoToApiGatewayToLambdaProps);
    /**
     * @summary Returns an instance of api.RestApi created by the construct.
     * @returns {api.RestApi} Instance of RestApi created by the construct
     * @since 0.8.0
     * @access public
     */
    restApi(): api.RestApi;
    /**
     * @summary Returns an instance of lambda.Function created by the construct.
     * @returns {lambda.Function} Instance of Function created by the construct
     * @since 0.8.0
     * @access public
     */
    lambdaFunction(): lambda.Function;
    /**
     * @summary Returns an instance of cognito.UserPool created by the construct.
     * @returns {cognito.UserPool} Instance of UserPool created by the construct
     * @since 0.8.0
     * @access public
     */
    userPool(): cognito.UserPool;
    /**
     * @summary Returns an instance of cognito.UserPoolClient created by the construct.
     * @returns {cognito.UserPoolClient} Instance of UserPoolClient created by the construct
     * @since 0.8.0
     * @access public
     */
    userPoolClient(): cognito.UserPoolClient;
}
